@@ -1,9 +1,11 @@
 package MaxMind::DB::Reader::XS;
-$MaxMind::DB::Reader::XS::VERSION = '1.000000';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '1.000001';
+
 use 5.010000;
 
 use Math::Int128 qw( uint128 );
@@ -18,13 +20,9 @@ with 'MaxMind::DB::Reader::Role::Reader',
 
 use XSLoader;
 
-XSLoader::load(
-    __PACKAGE__,
-    exists $MaxMind::DB::Reader::XS::{VERSION}
-        && ${ $MaxMind::DB::Reader::XS::{VERSION} }
-    ? ${ $MaxMind::DB::Reader::XS::{VERSION} }
-    : '42'
-);
+## no critic (Subroutines::ProhibitCallsToUnexportedSubs)
+XSLoader::load( __PACKAGE__, $VERSION );
+## use critic
 
 has _mmdb => (
     is        => 'ro',
@@ -45,6 +43,7 @@ has _flags => (
 
 sub BUILD { $_[0]->_mmdb }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _data_for_address {
     my $self = shift;
 
@@ -77,15 +76,6 @@ sub _build_metadata {
     return MaxMind::DB::Metadata->new($raw);
 }
 
-sub DEMOLISH {
-    my $self = shift;
-
-    $self->_close_mmdb( $self->_mmdb() )
-        if $self->_has_mmdb();
-
-    return;
-}
-
 sub _decode_bigint {
     my $buffer = shift;
 
@@ -98,6 +88,7 @@ sub _decode_bigint {
 
     return $int;
 }
+## use critic
 
 # Copied from MaxMind::DB::Reader::Decoder
 sub _zero_pad_left {
@@ -107,6 +98,15 @@ sub _zero_pad_left {
     return ( "\x00" x ( $desired_length - length($content) ) ) . $content;
 }
 
+sub DEMOLISH {
+    my $self = shift;
+
+    $self->_close_mmdb( $self->_mmdb() )
+        if $self->_has_mmdb();
+
+    return;
+}
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
@@ -117,15 +117,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 MaxMind::DB::Reader::XS - Fast XS implementation of MaxMind DB reader
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 SYNOPSIS
 
@@ -143,12 +141,21 @@ L<libmaxminddb|http://maxmind.github.io/libmaxminddb/> library.
 
 See L<MaxMind::DB::Reader> for API details.
 
+=for Pod::Coverage BUILD DEMOLISH
+
 =head1 VERSIONING POLICY
 
 This module uses semantic versioning as described by
 L<http://semver.org/>. Version numbers can be read as X.YYYZZZ, where X is the
 major number, YYY is the minor number, and ZZZ is the patch number.
 
+=head1 MAC OS X SUPPORT
+
+If you're running into install errors under Mac OS X, you may need to force a
+build of the 64 bit binary. For example, if you're installing via C<cpanm>:
+
+    ARCHFLAGS="-arch x86_64" cpanm MaxMind::DB::Reader::XS
+
 =head1 SUPPORT
 
 Please report all issues with this code using the GitHub issue tracker at
@@ -172,9 +179,25 @@ Ran Eilam <reilam@maxmind.com>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Greg Oschwald Olaf Alders
+
+=over 4
+
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Olaf Alders <oalders@maxmind.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc..
+This software is Copyright (c) 2015 by MaxMind, Inc..
 
 This is free software, licensed under:
 
